#
# spec file for package zoo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zoo
Version:        2.10
Release:        1028.3
Summary:        Pack Program
License:        SUSE-Public-Domain
Group:          Productivity/Archiving/Compression
URL:            https://en.wikipedia.org/wiki/Zoo_(file_format)
Source:         zoo.tar.gz
Patch0:         zoo.patch
Patch1:         zoo-%{version}-tempfile.patch
Patch2:         zoo-gcc.patch
Patch3:         zoo-%{version}-CAN-2005-2349.patch
Patch4:         zoo-return.patch
Patch5:         zoo-security_pathsize.patch
Patch6:         zoo-security_parse.patch
Patch7:         zoo-%{version}-security-infinite_loop.patch
Patch8:         zoo-fclose.patch
Patch9:         zoo-gcc14.patch

%description
Zoo is a packer based on the Lempel-Ziv algorithm. Lots of files on
DOS/AmigaDOS and TOS systems used this packer for their archives. The
compression rate of gzip is not reached, and thus zoo should only be used
for decompressing old archives.

%prep
%autosetup -n zoo -p0

%build
%make_build linux OPTIM="%{optflags}"

%install
install -Dpm 0755 zoo \
  %{buildroot}%{_bindir}/zoo
install -Dpm 0755 fiz \
  %{buildroot}%{_bindir}/fiz
install -Dpm 0644 zoo.1 \
  %{buildroot}/%{_mandir}/man1/zoo.1
install -Dpm 0644 fiz.1 \
  %{buildroot}/%{_mandir}/man1/fiz.1

%files
%license Copyright
%{_bindir}/fiz
%{_bindir}/zoo
%{_mandir}/man1/fiz.1%{?ext_man}
%{_mandir}/man1/zoo.1%{?ext_man}

%changelog
* Mon May 13 2024 Marcus Meissner <meissner@suse.com>
- zoo-gcc14.patch: fix build with gcc14, mostly implicits and type
  missmatches fixed.
* Tue Jun 23 2020 Martin Pluskal <mpluskal@suse.com>
- Use wikipedia as url
* Mon Jun 19 2017 mpluskal@suse.com
- Small packaging adjustements
* Fri Mar 13 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Tue Dec 23 2014 meissner@suse.com
- build with PIE support. stack-protector is now default
- zoo.patch: also include utime.h and unistd.h for some
  more prototypes to fix implicit warnings
* Fri Aug 22 2014 jengelh@inai.de
- Remove redundant %%clean section and old specfile tags;
  reset Release number as it is autocontrolled by OBS anyhow.
* Tue Nov 24 2009 crrodriguez@opensuse.org
- refresh patches with fuzz=0
* Thu Aug 13 2009 mseben@novell.com
- zoo-fclose.patch : use fclose to close fd (bnc#523301)
* Wed May  9 2007 lmichnovic@suse.cz
- fixed possible ZOO file decompression infinite loop DoS attack
  CVE-2007-1669 (security-infinite_loop.patch) [#271781]
* Mon Mar  6 2006 lmichnovic@suse.cz
- fixed buffer overflow (security_parse.patch) [155371]
* Fri Feb 24 2006 lmichnovic@suse.cz
- fixed security bug: buffer overflow when handling long filenames
  CVE-2006-0855 [#153057]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 lmichnovic@suse.cz
- wrote clean section
* Tue Jan 17 2006 lmichnovic@suse.cz
- enabled compilation with -fstack-protector
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
- Use RPM_OPT_FLAGS.
- Fix random return values.
* Mon Aug 15 2005 ro@suse.de
- fix typo in last change
* Mon Aug 15 2005 mjancar@suse.cz
- add check for ".." to the CAN-2005-2349 fix (#62234)
* Thu Aug 11 2005 anicka@suse.cz
- fix CAN-2005-2349 directory traversal bug (#62234)
* Thu Feb 26 2004 hmacht@suse.de
- building as non-root
* Mon Nov 25 2002 jderfina@suse.cz
- Replaced varargs.h with stdarg.h and adapted for new gcc.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jan 18 2002 okir@suse.de
- fix for tempfile race
* Thu Feb  8 2001 ro@suse.de
- fixed to compile
* Tue Aug 22 2000 nadvornik@suse.cz
- added buildroot
- fixed permissions
* Sat Feb 19 2000 kasal@suse.cz
- got rid of Makefile.Linux
- moved manpages to /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Nov  9 1998 ro@suse.de
- renamed function basename to my_basename to avoid conflict with glibc
* Thu Feb  6 1997 rj@suse.de
- new package (Version 2.10)
